# OctoPrintDeviceKey


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**active_session** | [**PrintSession**](PrintSession.md) |  | [optional] 
**ca_certs** | **dict(str, str)** |  | 
**cloudiot_device_configs** | **str** |  | [readonly] 
**cloudiot_device_name** | **str** |  | [readonly] 
**cloudiot_device_num_id** | **int** |  | [readonly] 
**cloudiot_device_path** | **str** |  | [readonly] 
**cloudiot_device** | **dict(str, object)** |  | [readonly] 
**cores** | **int** |  | 
**cpu_flags** | **list[str]** |  | [optional] 
**created_dt** | **datetime** |  | [readonly] 
**fingerprint** | **str** |  | [readonly] 
**hardware** | **str** |  | [optional] 
**id** | **int** |  | [readonly] 
**manage_url** | **str** |  | [readonly] 
**model** | **str** |  | 
**monitoring_active** | **bool** |  | [readonly] 
**name** | **str** |  | 
**octoprint_version** | **str** |  | 
**pip_version** | **str** |  | 
**platform** | **str** |  | 
**plugin_version** | **str** |  | 
**print_nanny_client_version** | **str** |  | 
**private_key_checksum** | **str** |  | [readonly] 
**private_key** | **str** |  | [readonly] 
**public_key_checksum** | **str** |  | 
**public_key** | **str** |  | [readonly] 
**python_version** | **str** |  | 
**ram** | **int** |  | 
**revision** | **str** |  | [optional] 
**serial** | **str** |  | 
**user** | **int** |  | [readonly] 
**url** | **str** |  | [readonly] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


